Learn R Programming

QRFCCA (version 1.0)

CCA_chisq_test: Chi-square Test for Canonical Correlation Analysis

Description

Calculate the chi-square test for canonical correlation analysis.

Usage

CCA_chisq_test(rho, n, p, q)

Arguments

rho

a vector of correlation coefficients.

n

The number of individuals.

p

The number of variables in the first set of variables.

q

The number of variables in the second set of variables.

Value

p-values between 0 and 1.

Details

Calculate the p-value of the chi-square test for canonical correlation analysis.

See Also

cca

Examples

Run this code
# NOT RUN {
     rlt = CCA_chisq_test(c(0.9,0.6,0.02),100,4,3);  
# }

Run the code above in your browser using DataLab