Learn R Programming

QRFCCA (version 1.0)

mrank_sq: Matrix rank of symetrix matrix

Description

Calcualte the matrix rank of a symetric matrix.

Usage

mrank_sq(X)

Arguments

X

X is the input data matrix and it should be a symetrix matrix.

Value

The rank of the symetrix matrix.

Details

Calculate the rank of the input data matrix by using eigen decomposition.

See Also

mrank

Examples

Run this code
# NOT RUN {
    X = matrix(rnorm(25,0,1),nrow=5,ncol=5);
    X_in = t(X) 
# }
# NOT RUN {
<!-- %*% X; -->
# }
# NOT RUN {
    rlt = mrank_sq(X_in);
# }

Run the code above in your browser using DataLab