Learn R Programming

QRFCCA (version 1.0)

p_ginv_sq: Power generalized inverse of a symetric matrix

Description

Calcualte the pwoer generated inverse of a symetric matrix by using eigen dicompostion.

Usage

p_ginv_sq(X, p)

Arguments

X

X is the data input matrix and it should be symetrix.

p

p is the power. For example, to calculate the inverse of X, p is set to be 1.

Value

The power inverse of the input matrix.

Details

p_ginv is use to calcuate X^(-p).

See Also

p_ginv

Examples

Run this code
# NOT RUN {
   X = matrix(rnorm(20,0,1),nrow=5,ncol=4);
   X_in = t(X) 
# }
# NOT RUN {
<!-- %*% X; -->
# }
# NOT RUN {
   pinv_X_in = p_ginv(X_in,2);
# }

Run the code above in your browser using DataLab