Learn R Programming

QRFCCA (version 1.0)

qcca_p: Quadratically Regularized Canonical Correlation Analysis with Low Rank Proportion

Description

Conduct quadratically regularized canonical correlation analysis by specifying the proportion of variance that the low rank approximation can explain.

Usage

qcca_p(A, A_prop, B, B_prop, Z = NULL)

Arguments

A

The first input data matrix.

A_prop

The proportion of variance that the low rank approximation can explain in matrix A.

B

The second input data matrix.

B_prop

The proportion of variance that the low rank approximation can explain in matrix B.

Z

The potential covariates for the canonical correaltion analysis. The default value for Z is NULL.

Value

The output is a list.

rho

a numeric vector of canonical correlation coefficients

chisq_p

p_value between 0 and 1 by using chi-square test

A_thres

The corresponding cut-off point for A_prop

B_thres

The corresponding cut-off point for B_prop

References

Lin N, Zhu Y, Fan R, Xiong M. A quadratically regularized functional canonical correlation analysis for identifying the global structure of pleiotropy with NGS data. PLOS Computational Biology. 2017;13(10):e1005788. doi: 10.1371/journal.pcbi.1005788.

See Also

CCA_chisq_test,cca,qcca

Examples

Run this code
# NOT RUN {
data(snp_data)
data(phe_data)
# }
# NOT RUN {
#obtain the snp position
sp = as.numeric(colnames(snp_data));
fs = fpca.score(snp_data,pos=sp,gename="Gene",percentage = 0.9,nbasis=45);
rlt = qcca_p(phe_data,0.8,fs$score,0.8,Z=NULL);
# }

Run the code above in your browser using DataLab