powered by
Calculate the chi-square test for canonical correlation analysis.
CCA_chisq_test(rho, n, p, q)
a vector of correlation coefficients.
The number of individuals.
The number of variables in the first set of variables.
The number of variables in the second set of variables.
p-values between 0 and 1.
Calculate the p-value of the chi-square test for canonical correlation analysis.
cca
# NOT RUN { rlt = CCA_chisq_test(c(0.9,0.6,0.02),100,4,3); # }
Run the code above in your browser using DataLab