powered by
Calcualte the matrix rank of a symetric matrix.
mrank_sq(X)
X is the input data matrix and it should be a symetrix matrix.
The rank of the symetrix matrix.
Calculate the rank of the input data matrix by using eigen decomposition.
mrank
# NOT RUN { X = matrix(rnorm(25,0,1),nrow=5,ncol=5); X_in = t(X) # } # NOT RUN { <!-- %*% X; --> # } # NOT RUN { rlt = mrank_sq(X_in); # }
Run the code above in your browser using DataLab