powered by
Calcualte the pwoer generated inverse of a symetric matrix by using eigen dicompostion.
p_ginv_sq(X, p)
X is the data input matrix and it should be symetrix.
p is the power. For example, to calculate the inverse of X, p is set to be 1.
The power inverse of the input matrix.
p_ginv is use to calcuate X^(-p).
p_ginv
# NOT RUN { X = matrix(rnorm(20,0,1),nrow=5,ncol=4); X_in = t(X) # } # NOT RUN { <!-- %*% X; --> # } # NOT RUN { pinv_X_in = p_ginv(X_in,2); # }
Run the code above in your browser using DataLab